#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from z3c.form import field
from z3c.form.browser.checkbox import SingleCheckBoxFieldWidget

from pyams_form.form import ajax_config
from pyams_form.group import NamedWidgetsGroup
from pyams_pagelet.pagelet import pagelet_config
from pyams_skin.interfaces import IUserSkinnable
from pyams_skin.layer import IPyAMSLayer
from pyams_skin.viewlet.menu import MenuDivider, MenuItem
from pyams_utils.interfaces import MANAGE_SKIN_PERMISSION
from pyams_viewlet.viewlet import viewlet_config
from pyams_zmi.form import AdminDialogEditForm
from pyams_zmi.interfaces.menu import IPropertiesMenu
from pyams_zmi.layer import IAdminLayer

from pyams_zmi import _


#
# User skinnable properties configuration
#

@viewlet_config(name='user-skin-properties.divider', context=IUserSkinnable, layer=IAdminLayer, manager=IPropertiesMenu,
                permission=MANAGE_SKIN_PERMISSION, weight=199)
class UserSkinnablePropertiesMenuDivider(MenuDivider):
    """User skin properties menu divider"""


@viewlet_config(name='user-skin-properties.menu', context=IUserSkinnable, layer=IAdminLayer, manager=IPropertiesMenu,
                permission=MANAGE_SKIN_PERMISSION, weight=200)
class UserSkinnablePropertiesMenuItem(MenuItem):
    """User skin properties menu"""

    label = _("Graphic theme...")
    icon_class = 'fa-paint-brush'
    url = 'user-skin-properties.html'
    modal_target = True


@pagelet_config(name='user-skin-properties.html', context=IUserSkinnable, layer=IPyAMSLayer,
                permission=MANAGE_SKIN_PERMISSION)
@ajax_config(name='user-skin-properties.json', context=IUserSkinnable, layer=IPyAMSLayer)
class UserSkinnablePropertiesEditForm(AdminDialogEditForm):
    """User skin properties edit form"""

    prefix = 'skin_properties.'

    legend = _("Graphic theme elements")
    label_css_class = 'control-label col-md-4'
    input_css_class = 'col-md-8'

    @property
    def fields(self):
        fields = field.Fields(IUserSkinnable).select('no_inherit_skin', 'skin', 'custom_stylesheet',
                                                     'editor_stylesheet', 'custom_script')
        if self.context.can_inherit_skin:
            fields['no_inherit_skin'].widgetFactory = SingleCheckBoxFieldWidget
        else:
            fields = fields.omit('no_inherit_skin')
        return fields

    ajax_handler = 'user-skin-properties.json'
    edit_permission = MANAGE_SKIN_PERMISSION

    def updateGroups(self):
        if self.context.can_inherit_skin:
            self.add_group(NamedWidgetsGroup(self, 'skin', self.widgets,
                                             ('no_inherit_skin', 'skin', 'custom_stylesheet',
                                              'editor_stylesheet', 'custom_script'),
                                             legend=_("Don't inherit parent skin"),
                                             css_class='inner',
                                             switch=True,
                                             checkbox_switch=True,
                                             checkbox_mode='disable',
                                             checkbox_field=IUserSkinnable['no_inherit_skin']))
        super(UserSkinnablePropertiesEditForm, self).updateGroups()
